@@ -27,6 +27,8 @@ class Settings:
             if setting.isupper():
                 setattr(self, setting, getattr(globals, setting))
         self.end_event = threading.Event()
+        # To store XOFF_RECV, XOFF_SENT stream events
+        self.stream_event = {}
 
     def init_http_headers(self, nickname, uuid, tor_version):
         self.HTTP_HEADERS["Tor-Bandwidth-Scanner-Nickname"] = nickname
