@@ -159,7 +159,6 @@ def configure_logging(args, conf):
         # the sbws command (like 'scanner' or 'generate') if possible, or to
         # 'sbws' failing that.
         dname = conf.getpath("paths", "log_dname")
-        os.makedirs(dname, mode=0o700, exist_ok=True)
         fname = os.path.join(dname, "{}.log".format(args.command or "sbws"))
         # The second argument is the file mode, and it should be left alone
         mode = "a"
@@ -668,7 +667,7 @@ def _validate_url(section, key):
     # When the scheme is https but the protocol is not TLS, requests will hang.
     # For tests we use 127.0.0.1, allow this address without https scheme.
 
-    if url.scheme != "https" and url.netloc.split(":")[0] != "127.0.0.1":
+    if url.scheme != "https" and url.hostname != "127.0.0.1":
         return False, "URL scheme must be HTTPS (except for the test server)"
     return True, ""
 
